getsteadystatepop <- function(guilds,paramList,nf,cellsize,plotbool=TRUE){
  
  #PURPOSE:
  #This function repeatedly calls the function 'runpop_bird' (which simulates bird foraging and population processes) until the steady state population is reached. 
  
  #INPUTS:
  #guilds = a vector giving the names of the bird guilds to be simulated, where the names must match those used in the input parameter file 'bird_guild_params.csv'.
  #paramList = a list of the input parameters containing two items: the first item, 'guild_params', should contain the contents of the 'bird_guild_params.csv' file and the second item, 'habitat_params', should contain the contents of the 'bird_habitat_params.csv' file. 
  #nf = the outputs produced by the 'computeForageNesting' function, which is a list containing two items: the first item, 'nest', contains the nesting resource maps (raster stack) for each bird guild. The second item, 'forage', contains the foraging resource maps (raster stack) for each bird guild.
  #cellsize = pixel size in meters of the original landscape raster (and therefore also of the rasters in 'nf') in meters, e.g. if input landscape has 10m x 10m pixels then cellsize should be set equal to 10. 
  #plotbool = if plotbool equals "TRUE" then the nesting and foraging resource maps, steady state population distribution and foraging rate maps for each guild are plotted. 
  
  #OUTPUTS:
  #pops0 = the outputs from the final run of the 'runpop_bird' function, which contains the steady state population distribution and foraging rate maps (list of raster stacks) for each guild.  
	
	#Get number of guilds to model
	num_guilds = length(guilds)
	
	#Do first year
	pops = runpop_bird(P_pop0=numeric(0),nestlocs0=numeric(0),firstyearbool=TRUE,cellsize=cellsize,guilds=guilds,paramList=paramList,resources=nf)
	pops0 = pops
	
	#Do subsequent years until reach steady state population
	print("Calculating steady state populations:")
	diff_perguild = rep(100,num_guilds)
	while (max(diff_perguild)>0.01)
	  {pops = runpop_bird(P_pop0=pops0$P_pop,nestlocs0=pops0$nestlocs,firstyearbool=FALSE,cellsize=cellsize,guilds=guilds,paramList=paramList,resources=nf)
	  #Calculate fractional change in adult population size
	  for (s in 1:num_guilds)
	    {num = sum(values(pops$P_pop[[s]][[7]]))
	    num0 = sum(values(pops0$P_pop[[s]][[7]]))
	    print(c(num,num0))
	    diff_perguild[s] = abs((num-num0)/num0)
	    if ((num0==0.0)&(num==0.0))
	      {diff_perguild[s] = 0.0
	    }
	  }
	  print(diff_perguild)
	  pops0 = pops
	  #diff_perguild = c(0.0,0.0,0.0)
	}
	
	#Plot
	if (plotbool==TRUE)
	  {for (s in 1:num_guilds)
	  {#Plot resources and nest locations
		rasters_s = stack(nf$nest[[s]][[1]],nf$forage[[s]][[1]])
		names(rasters_s) = c(paste(guilds[s],":Nest resources"),paste(guilds[s],":Forage resources"))
		#plot(rasters_s)
		#Plot population size/distribution (multi-panel)
		rasters_s = stack(pops$P_pop[[s]][[1]],pops$P_pop[[s]][[2]],pops$P_pop[[s]][[3]],pops$P_pop[[s]][[4]],pops$P_pop[[s]][[5]],pops$P_pop[[s]][[6]],pops$P_pop[[s]][[7]])
		names(rasters_s)= c(paste(guilds[s],":breeding pairs"),paste(guilds[s],":offspring fledged"),paste(guilds[s],":adults after mort"),paste(guilds[s],":offspring after mort"),paste(guilds[s],":total surviving birds after dispersal"),paste(guilds[s],":pairs before nesting lim"),paste(guilds[s],":pairs after nesting lim"))
		#plot(rasters_s)
		#Plot foraging rates
		plot(pops$forvis[[s]],main=paste(guilds[s],":Foraging activity"))
		#Plot resources gathered
		#plot(pops$resgath[[s]],main=paste(guilds[s],":Resources gathered"))
	  }
	}
	
	return(list(pops0=pops0))
	
}